![pytest](https://github.com/ppak10/amdt/workflows/pytest/badge.svg)

# Additive Manufacturing Digital Twin (AMDT)

## Getting Started
- Install local package with:
  ```bash
  pip install -e .
  ```
